==> bayes4psy_1.1.1.tar.gz: bayes4psy/NEWS.md <==
# bayes4psy 1.1.0

### New features and improvements
Modified some examples due to CRAN revision.
Beautified some outputs.
T-test now supports comparison through the sigma parameter only.


# bayes4psy 1.1.0

### New features and improvements
Examples for all models and fitting functions.
Code tests for all core functions.
Documentation amended in accordance with CRAN team comments.


# bayes4psy 1.0.2

### New features and improvements
Compilation is now c++14 compliant.
Minor update to one of color visualizations.


# bayes4psy 1.0.1

### New features and improvements
Ran CRAN checks (spell check, ...) and fixed some minor issues according to feedback.


# bayes4psy 1.0.0

### New features and improvements
Greatly expanded the readme file.
Minor changes to a few documentation entries.
CRAN publish preparations.


# bayes4psy 0.9.0

### New features and improvements
Various quality of life improvements (nicer graphs and outputs).
Package is not in its own repository so it can be installed from GitHub via devtools.
Upgraded all examples and tests.
Examples and tests are now in a separate repository.


# bayes4psy 0.8.0

### New features and improvements
Renamed package from EasyBayes to bayes4psy.
Parameters are no longer permuted when extracted from a Stan fit.


# bayes4psy 0.7.0

### New features and improvements
Functions for comparing multiple fits at the same time.
Revised prior system so it is now more user friendly.
Implementation of Bayesian t-test.


# bayes4psy 0.6.0

### New features and improvements
Flexible setting of priors on all of the model's parameters.
The plot_fit function for hierarchical models now allows visual inspection of a fit on top and bottom levels.
Added functions for easy extraction of parameter values.


# bayes4psy 0.5.0

### New features and improvements
Color model implementation.
Specific visualizations for colors.
Success rate hierarchical model rework.
Extended documentation.
Multiple chains support.


# bayes4psy 0.4.0

### New features and improvements
Large update to documentation, which is now CRAN compliant.
Added an additional, more detailed diagnostic print of fit.
Updates to various visualizations.
Bayesian bootstrap implementation.
Tidyverse style code.


# bayes4psy 0.3.0

### New features and improvements
Removed all warnings.
CRAN ready!


# bayes4psy 0.2.0

### New features and improvements
Cross platform compilation.
Package now passes CRAN checks (with a lot of warnings and notes).
Added documentation.


# bayes4psy 0.1.4

### New features and improvements
Integrated linear model into the package.
Changed version numbering.
Using HDI instead of CI now.


# bayes4psy 0.1.3

### New features and improvements
Expanded documentation of functions and classes. Consolidate functions and parameter passing between all models.


# bayes4psy 0.1.2

### New features and improvements
Implementation of the success rate model.


# bayes4psy 0.1.1

### New features and improvements
Implementation of ttest model.
Implementation of reaction times model.

==> bayes4psy_1.2.0.tar.gz: bayes4psy/NEWS.md <==
# bayes4psy 1.2.0

### New features and improvements
Added detailed examples of usage as vignettes.
All models now create visualizations with the default R plot function.
Several minor tweaks and improvements.


# bayes4psy 1.1.1

### New features and improvements
Modified some examples due to CRAN revision.
Beautified some outputs.
T-test now supports comparison through the sigma parameter only.


# bayes4psy 1.1.0

### New features and improvements
Examples for all models and fitting functions.
Code tests for all core functions.
Documentation amended in accordance with CRAN team comments.


# bayes4psy 1.0.2

### New features and improvements
Compilation is now c++14 compliant.
Minor update to one of color visualizations.


# bayes4psy 1.0.1

### New features and improvements
Ran CRAN checks (spell check, ...) and fixed some minor issues according to feedback.


# bayes4psy 1.0.0

### New features and improvements
Greatly expanded the readme file.
Minor changes to a few documentation entries.
CRAN publish preparations.


# bayes4psy 0.9.0

### New features and improvements
Various quality of life improvements (nicer graphs and outputs).
Package is not in its own repository so it can be installed from GitHub via devtools.
Upgraded all examples and tests.
Examples and tests are now in a separate repository.


# bayes4psy 0.8.0

### New features and improvements
Renamed package from EasyBayes to bayes4psy.
Parameters are no longer permuted when extracted from a Stan fit.


# bayes4psy 0.7.0

### New features and improvements
Functions for comparing multiple fits at the same time.
Revised prior system so it is now more user friendly.
Implementation of Bayesian t-test.


# bayes4psy 0.6.0

### New features and improvements
Flexible setting of priors on all of the model's parameters.
The plot_fit function for hierarchical models now allows visual inspection of a fit on top and bottom levels.
Added functions for easy extraction of parameter values.


# bayes4psy 0.5.0

### New features and improvements
Color model implementation.
Specific visualizations for colors.
Success rate hierarchical model rework.
Extended documentation.
Multiple chains support.


# bayes4psy 0.4.0

### New features and improvements
Large update to documentation, which is now CRAN compliant.
Added an additional, more detailed diagnostic print of fit.
Updates to various visualizations.
Bayesian bootstrap implementation.
Tidyverse style code.


# bayes4psy 0.3.0

### New features and improvements
Removed all warnings.
CRAN ready!


# bayes4psy 0.2.0

### New features and improvements
Cross platform compilation.
Package now passes CRAN checks (with a lot of warnings and notes).
Added documentation.


# bayes4psy 0.1.4

### New features and improvements
Integrated linear model into the package.
Changed version numbering.
Using HDI instead of CI now.


# bayes4psy 0.1.3

### New features and improvements
Expanded documentation of functions and classes. Consolidate functions and parameter passing between all models.


# bayes4psy 0.1.2

### New features and improvements
Implementation of the success rate model.


# bayes4psy 0.1.1

### New features and improvements
Implementation of ttest model.
Implementation of reaction times model.
